@@ -3,8 +3,16 @@ from datetime import datetime
 
 
 def convert_time_str_to_datetime(time_str_series):
+    # find first non nan value
+    idx = 0
+    for i in range(len(time_str_series)):
+        if type(time_str_series[i]) == str:
+            idx = i
+            break
+    else:
+        return time_str_series
 
-    if len(time_str_series[0].split(".")) > 1:
+    if len(time_str_series[idx].split(".")) > 1:
         converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f") if (type(x) == str) else x
     else:
         converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S") if (type(x) == str) else x
