@@ -15,7 +15,7 @@ import mhealthlab_client.mhlab as mhlab
 #
 #     return unzip_file_path
 def uncompress(zip_file_path, password):
-    password_bytes = password.encode('utf-8')
+    #password_bytes = password.encode('utf-8')
     unzip_file_name = zip_file_path.split(os.sep)[-1].split(".zip")[0]
     zip_folder_path = os.path.abspath(os.path.join(zip_file_path, os.pardir))
     mhlab.decrypt_file(zip_file_path, zip_folder_path, password.encode())
